@@ -374,9 +374,13 @@ class MainWindow:
             self.show_info_banner(widget, 'No selected recipe')
             return
 
+        elif selection.count_selected_rows() == 1:
+            title = "Delete recipe?"
+        else:
+            title = "Delete recipes?"
+
         #show confirmation dialog
-        confirmation = pyrecipe_utils.on_confirmation(self.window,
-                        'Delete recipes?')
+        confirmation = pyrecipe_utils.on_confirmation(self.window, title)
 
         if confirmation == True:
             try:
@@ -1060,7 +1064,12 @@ class MainWindow:
                 return
 
     def add_ingredient_dlg(self, widget, amount, unit, ing, edit, seliter):
-        dlg = gtk.Dialog(title='Add ingredient', parent=None, flags=0)
+        if edit:
+            title = "Edit ingredient"
+        else:
+            title = "Add ingredient"
+
+        dlg = gtk.Dialog(title=title, parent=None, flags=0)
         dlg.set_has_separator(False)
 
         self.ening = hildon.Entry(fhsize)
@@ -1731,6 +1740,21 @@ class Log:
             MainWindow.show_info_banner(widget, 'Error saving the log file')
 
     def send(self, widget, dlg, logfile):
+        sendtxt = ("You are going to send the log to the developers.\n"
+        "This helps the developers to track problems with the application.\n"
+        "It doesn't send any personal information (like passwords or similar).")
+
+        dialog = hildon.hildon_note_new_confirmation(dlg, sendtxt)
+        dialog.set_button_texts("Send", "Cancel")
+        dialog.show_all()
+        response = dialog.run()
+        if response == gtk.RESPONSE_OK:
+            self.do_pre_send(dlg, logfile)
+
+        dialog.destroy()
+
+
+    def do_pre_send(self, dlg, logfile):
         import thread
         hildon.hildon_gtk_window_set_progress_indicator(dlg, 1)
         thread.start_new_thread(self._do_send, (dlg, logfile))
